/*
 * Copyright 2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.external.javadoc;

import org.gradle.external.javadoc.internal.JavadocOptionFileWriterContext;
import org.gradle.internal.HasInternalProtocol;

import java.io.IOException;

/**
 * Represents a Javadoc option.
 *
 * @param <T> The type which this option represents.
 */
@HasInternalProtocol
public interface OptionLessJavadocOptionFileOption<T> {
    T getValue();

    void setValue(T value);

    void write(JavadocOptionFileWriterContext writerContext) throws IOException;
}
